==> neper-1.8.0.tgz: neper-1.8.0/src/neper_t/PolyComp/PolyDet/PolyCalc/PolyCalc.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<gsl/gsl_linalg.h>

#include"../../../../Structs/structAll.h"
/* #include"../../../DnGDistrib/GermsNei/GermsNei0.h" */
#include"../../../../Utils/AllUtils.h"
#include"../../../../ut/ut.h"

extern void PolyhedronCalculation (int, struct GERMSET, struct INTEPARA*, struct POLYMOD *);
extern void NewPolyhedron (int, int, struct GERMSET, struct POLYMOD *);
extern void PlanePara (int, int, struct GERMSET, double *);
extern void NewFace (int, struct POLYMOD *, double *);
extern void BadVerDet (int, double *, struct GERMSET, struct POLYMOD, int *);
extern void VerUseUpdating (struct POLYMOD *, int *);
extern void FaceUseUpdating (struct POLYMOD *, int *);
extern int CheckFace (int *, struct POLYMOD, int);

extern void PolyhedronModification (int, double *, struct POLYMOD *, int *);
extern int FaceModif (int, int, struct POLYMOD *, int *, int);
extern int VerCoupleNFaces (struct POLYMOD *, int *, int, int, int *, int *,
			    int *, int *, int *);
extern void FaceModifGenPara (struct POLYMOD *, int, int);
extern void FaceModif1stNewVer (struct POLYMOD *, int);
extern int FaceModif2ndNewVer (struct POLYMOD *, int, int, int *, int *);
extern void FaceModifAddBegVer (struct POLYMOD *, int, int, int);
extern void FnLFacesDet (struct POLYMOD, int *, int *);
extern double MaxiDist (int, struct GERMSET, struct POLYMOD);
extern int CurrentPolyTest (double, double);

extern int NewVer (struct POLYMOD *, int, int, int);
extern void NewFaceAddVer (struct POLYMOD *);
extern int CommonFaces (struct POLYMOD, int, int, int *);

extern void UpdFaceQty (struct POLYMOD *);
extern void UpdFaceEq (struct POLYMOD *, double *);
extern void UpdFaceUse (struct POLYMOD *);
extern void UpdFaceGerm (struct POLYMOD *, int);
extern void UpdVerQty (struct POLYMOD *);
extern void UpdVerUse (struct POLYMOD *);
extern void UpdVerFace (struct POLYMOD *, int, int, int);
extern void UpdVerCoo (struct POLYMOD *, int, int, int);
extern void UpdFaceVerQty (struct POLYMOD *);
extern void UpdFaceVerNb (struct POLYMOD *);
extern int RotFaceVerNb (struct POLYMOD *, int *, int);

extern void SnNS (struct POLYMOD, int, int, int *, int *);
extern int NeiVer (struct POLYMOD, int, int, int);

extern void PolyDescription (int, struct POLY);
extern void PolymodDescription (int, struct POLYMOD);
extern void Error (int);
extern void NeiSearching (struct GERMSET, int, int, int*, double*);

==> neper-1.8.1.tgz: neper-1.8.1/src/neper_t/PolyComp/PolyDet/PolyCalc/PolyCalc.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<gsl/gsl_linalg.h>

#include"../../../../Structs/structAll.h"
/* #include"../../../DnGDistrib/GermsNei/GermsNei0.h" */
#include"../../../../Utils/AllUtils.h"
#include"../../../../ut/ut.h"

extern void PolyhedronCalculation (int, struct GERMSET, struct INTEPARA *,
				   struct POLYMOD *);
extern void NewPolyhedron (int, int, struct GERMSET, struct POLYMOD *);
extern void PlanePara (int, int, struct GERMSET, double *);
extern void NewFace (int, struct POLYMOD *, double *);
extern void BadVerDet (int, double *, struct GERMSET, struct POLYMOD, int *);
extern void VerUseUpdating (struct POLYMOD *, int *);
extern void FaceUseUpdating (struct POLYMOD *, int *);
extern int CheckFace (int *, struct POLYMOD, int);

extern void PolyhedronModification (int, double *, struct POLYMOD *, int *);
extern int FaceModif (int, int, struct POLYMOD *, int *, int);
extern int VerCoupleNFaces (struct POLYMOD *, int *, int, int, int *, int *,
			    int *, int *, int *);
extern void FaceModifGenPara (struct POLYMOD *, int, int);
extern void FaceModif1stNewVer (struct POLYMOD *, int);
extern int FaceModif2ndNewVer (struct POLYMOD *, int, int, int *, int *);
extern void FaceModifAddBegVer (struct POLYMOD *, int, int, int);
extern void FnLFacesDet (struct POLYMOD, int *, int *);
extern double MaxiDist (int, struct GERMSET, struct POLYMOD);
extern int CurrentPolyTest (double, double);

extern int NewVer (struct POLYMOD *, int, int, int);
extern void NewFaceAddVer (struct POLYMOD *);
extern int CommonFaces (struct POLYMOD, int, int, int *);

extern void UpdFaceQty (struct POLYMOD *);
extern void UpdFaceEq (struct POLYMOD *, double *);
extern void UpdFaceUse (struct POLYMOD *);
extern void UpdFaceGerm (struct POLYMOD *, int);
extern void UpdVerQty (struct POLYMOD *);
extern void UpdVerUse (struct POLYMOD *);
extern void UpdVerFace (struct POLYMOD *, int, int, int);
extern void UpdVerCoo (struct POLYMOD *, int, int, int);
extern void UpdFaceVerQty (struct POLYMOD *);
extern void UpdFaceVerNb (struct POLYMOD *);
extern int RotFaceVerNb (struct POLYMOD *, int *, int);

extern void SnNS (struct POLYMOD, int, int, int *, int *);
extern int NeiVer (struct POLYMOD, int, int, int);

extern void PolyDescription (int, struct POLY);
extern void PolymodDescription (int, struct POLYMOD);
extern void Error (int);
extern void NeiSearching (struct GERMSET, int, int, int *, double *);
